import numpy as np
from skimage.color import rgb2gray
from skimage.exposure import match_histograms
from skimage.metrics import structural_similarity

def procurar_diferenciacao(imagem1, imagem2):
    assert imagem1.shape == imagem2.shape, "Especifique 2 imagens com a mesma forma."
    cinza1 = rgb2gray(imagem1)
    cinza2 = rgb2gray(imagem2)
    (score, diferenca_imagem) = structural_similarity(cinza1, cinza2, full=True)
    print("Semelhança das imagens:", score)
    imagem = (diferenca_imagem-np.min(diferenca_imagem))/(np.max(diferenca_imagem)-np.min(diferenca_imagem))
    return imagem

def transferir_histograma(imagem1, imagem2):
    imagem = match_histograms(imagem1, imagem2, multichannel=True)
    return imagem


import matplotlib.pyplot as plt

def plot_imagem(imagem):
    plt.figure(figsize=(12, 4))
    plt.imshow(imagem, cmap='gray')
    plt.axis('off')
    plt.show()

def plot_resultado(*args):
    imagens = len(args)
    fig, axis = plt.subplots(nrows=1, ncols = imagens, figsize=(12, 4))
    nomes = ['imagem {}'.format(i) for i in range(1, imagens)]
    nomes.append('Resultado')
    for ax, nome, imagem in zip(axis, nomes, args):
        ax.set_title(nome)
        ax.imshow(imagem, cmap='gray')
        ax.axis('off')
    fig.tight_layout()
    plt.show()

def plot_histograma(imagem):
    fig, axis = plt.subplots(nrows=1, ncols = 3, figsize=(12, 4), sharex=True, sharey=True)
    color_lst = ['vermelho', 'verde', 'azul']
    for index, (ax, color) in enumerate(zip(axis, color_lst)):
        ax.set_title('{} histograma'.format(color.title()))
        ax.hist(imagem[:, :, index].ravel(), bins = 256, color = color, alpha = 0.8)
    fig.tight_layout()
    plt.show()


from skimage.io import imread, imsave

def ler_imagem(caminho, cinza = False):
    imagem = imread(caminho, as_gray = cinza)
    return imagem

def salvar_imagem(imagem, caminho):
    imsave(caminho, imagem) 


from setuptools import setup, find_packages

with open("README.md", "r") as f:
    page_description = f.read()

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

setup(
    name="processamento_de_imagem",
    version="0.0.1",
    author="Jhonathan Alves",
    description="Processamento de imagem usando combinação de histograma",
    long_description=page_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Jhonathanalvesbr/processamento-de-imagem",
    packages=find_packages(),
    package_data = {
        "processamento_de_imagem": ["sample_images/*.jpg"]
    },
    include_package_data = True,
    install_requires=requirements,
    python_requires='>=3.5',
)